from django import forms
from django.forms import ModelForm, ImageField, FileField

from ckeditor.fields import RichTextField
from filer.models.imagemodels import Image
from filer.models.filemodels import File

from aircox.models import Comment, Episode, Program
from aircox.controllers.sound_file import SoundFile


class CommentForm(ModelForm):
    nickname = forms.CharField()
    email = forms.EmailField(required=False)
    content = forms.CharField(widget=forms.Textarea())

    nickname.widget.attrs.update({"class": "input"})
    email.widget.attrs.update({"class": "input"})
    content.widget.attrs.update({"class": "textarea"})

    class Meta:
        model = Comment
        fields = ["nickname", "email", "content"]


class ProgramForm(ModelForm):
    content = RichTextField()
    new_cover = ImageField(required=False)

    class Meta:
        model = Program
        fields = ["content"]

    def save(self, commit=True):
        file_obj = self.cleaned_data["new_cover"]
        if file_obj:
            obj, _ = Image.objects.get_or_create(original_filename=file_obj.name, file=file_obj)
            self.instance.cover = obj
        super().save(commit=commit)


class EpisodeForm(ModelForm):
    content = RichTextField()
    new_podcast = FileField(required=False)

    class Meta:
        model = Episode
        fields = ["content"]

    def save(self, commit=True):
        file_obj = self.cleaned_data["new_podcast"]
        if file_obj:
            obj, _ = File.objects.get_or_create(original_filename=file_obj.name, file=file_obj)
            sound_file = SoundFile(obj.path)
            sound_file.sync(
                program=self.instance.program, episode=self.instance, type=0, is_public=True, is_downloadable=True
            )
        super().save(commit=commit)
